@@ -1,7 +1,9 @@
-package Pcore::Nginx v1.1.1;
+package Pcore::Nginx v1.1.2;
 
 use Pcore -dist, -class, -try;
-use Pcore::GeoIP;
+
+# TODO eval
+# use Pcore::GeoIP;
 
 has data_dir     => ( is => 'ro',   isa => Str, default => "$ENV->{DATA_DIR}" );
 has nginx_bin    => ( is => 'lazy', isa => Str, default => 'nginx' );
